@@ -1,5 +1,5 @@
-__author__ = "Lucas Grulich (lucasgrulich@gmx.de)"
-__version__ = "0.0.10"
+__author__ = "Lucas Grulich (grulich@uni-mainz.de)"
+__version__ = "0.0.14"
 
 # --- Globals ----------------------------------------------------------------------------------------------------------
 MONOSCALE_SHADOWLEVEL = 1
